function [data,n,nStr,params]=GcTmSybr(wellnumbers,temp,sybrWell,limit)
%
% [data,n,nStr,params]=GcTmSybr(wellnumbers,temp,sybrWell)
%
if nargin<4, limit=1.2; end
[Nwell, NT]=size(sybrWell);
data=zeros(Nwell,2);                            % Tmax Smax
n=zeros(Nwell,6);                               % arrow position
nStr=['n1'; 'n2'; 'n3'; 'n4'; 'n5'; 'n0'];      % arrows strings
params=zeros(Nwell,5);                          % curve fitting parameters a-e

% Check all wells for peaks to get a start position
pos = m_findPeak(sybrWell,limit);                           %limit=1.2
n0=find(any(pos),1,'first');

if isempty(n0),
    % no start point found
    return;
end


% Check each well
posPeak=false(1,NT);

for i = 1:Nwell,
    sybr_i=sybrWell(i,:);
    pos = abs(sybr_i-mean(sybr_i))>=limit*std(sybr_i);      %limit=1.0
    % if more than 4 data points 
    if any(pos),
        posPeak(n0:end) =m_findPeak(sybr_i(n0:end),limit);  %limit=1.5        
        n1=find(posPeak,1,'first');
        posLower = sybr_i(n1+1:end) <= sybr_i(n1);
        n2 = find(min(temp(posLower))==temp,1,'last')+n1;
        peakSig=sybr_i(n1:n2);
        peakTemp=temp(n1:n2);

        if length(peakSig)>5,
            options = optimset('Display', 'off');
            param=m_paramInti(peakTemp, peakSig);
            param=lsqcurvefit(@gausfn, param, peakTemp, peakSig,[],[], options);

            % Find min left of max
            n3=n1;
            for ii=n1:-1:1,
                if sybr_i(n3) > sybr_i(n3-1),
                    n3=n3-1;
                end
            end

            % Find n4, Start index for tamra
            n4=n2;
            n5=n3;
            for ii=n2:NT,
                if sybr_i(n4)>sybr_i(n5),
                    n4=n4+1;
                    n5=n5+1;
                end
            end

            data(i,:)=[param(2) param(1)];  %2=Tmax, 1=sybrMax
            n(i,:)=[n1 n2 n3 n4 n5 n0];
            params(i,:)=param;
        end
    end
    if rem(i,5)==0,
        % update progress 
        GcTmCmd('status',['SYBR well ' int2str(i)]);
    end
end

function pos=m_findPeak(well,limit)
pos = abs(well-mean(well(:)))>=limit*std(well(:));

function param=m_paramInti(x,y);
d=0;
e=min(y);
pdf=y-e;
a=max(pdf);
pdf=pdf/sum(pdf);
b=sum(pdf.*x);
v= sum(pdf.*(x-b).^2);
c=sqrt(v);
param =[a,b,c,d,e];


