function dataStruct=readCsvFile(fileName)
%
% dataStruct=readCsvFile(fileName,show)
% Reads csv data file to struct

dataStruct(1).type=[];
dataStruct(1).meshCol=12;
dataStruct(1).meshRow=8;
dataStruct(1).wellMax=8*12;
dataStruct(2)=dataStruct(1);

if nargin<1, error('No input file'); end
if isempty(fileName), error('No input file'); end
if ~exist([fileName],'file'), error('File does not exist'); end
if fileName(end)=='\', return; end
try   fp=fopen([fileName],'r');
catch
    error('Can not find file');
    return;
end

dataSet=0;
newLineFlag=0;
while 1
    if newLineFlag==0,
        % Do not read new line when getWellData called
        tline = fgetl(fp);
    else
        newLineFlag=0;
    end
    if ~ischar(tline), break, end % end of file no more data
    if strfind(tline,'Detector ='),
        % Get detector type
        detector=strtok(tline,';');
        if ~isempty(strfind(detector,'SYBR')),
            dataSet=1;
            dataStruct(dataSet).type='SYBR';
            dataStruct(dataSet).detector=detector;
        elseif ~isempty(strfind(detector,'TAMRA')),
            dataSet=2;
            dataStruct(dataSet).type='TAMRA';
            dataStruct(dataSet).detector=detector;
        else
            error(['Unknown detector: ' detector])
            return;
        end
    elseif strfind(tline,'Well'),
        % Get Well data
        [str1,tlineRest]=strtok(tline,';');
        str2=strtok(tlineRest,';');
        if strfind(tline,'Temperatures'),
            [data,number]=getWellData;
            dataStruct(dataSet).temperature=data(1,:);
            dataStruct(dataSet).wellNr=number;
        elseif strfind(tline,'Raw Data'),
            dataStruct(dataSet).rawData=getWellData;
        elseif strfind(tline,'Derivative Data'),
            dataStruct(dataSet).derivativeData=getWellData;
        else
            error(['Unknown data type' str1 ' ' str2])
        end
    end
end
fclose(fp);

if ~strcmp(dataStruct(1).type,'SYBR'), error('1. Error reading file'); end
try
    if ~strcmp(dataStruct(2).type,'TAMRA'), error('1. Error reading file'); end
catch
    dataStruct(2).type=[];
end

%---------------------------------------------------------------
    function [data,wellNr]=getWellData
    % Nested function to read well data
    % Last tline must not be lost by readeing a new line in readCsvFile    
    % Changeing fp, tline and newLineFlag in readCsvFile
    
        data=[];
        i=0;
        newLineFlag=1;
        while 1
            tline = fgetl(fp);
            if ~ischar(tline), break, end % end of file no more data
            % Convert from string to double data
            vector=str2num(tline);
            if isempty(vector),
                % last data read
                break;
            else
                i=i+1;
                wellNr(i)=vector(1);
                data(i,:)=vector(2:end);
            end
        end
    end
%---------------------------------------------------------------

end





